/*
 * main.c
 * Digital-Analog Conversion mit dem MSP430 und dem MCP42921
 *
 * Beispiel fr die Ausgabe von DAC-Werten via SPI an den 12-Bit DAC MCP4921
 *
 * Erzeugt eine Sinus-Schwingung maximaler Frequenz (ca. 22Hz) via MCP4921-DAC,
 * mit 4*32 Sttzstellen pro Periode werden die Sinus-Werte ausgegeben.
 * MSP430 luft mit ca. 1MHz
 *
 * Anschlussbelegung des MCP4921:
 * PIN 1  -   ./.  -  VDD   = +3,3V
 * PIN 2  -  P1.3  -  _CS - Chip select
 * PIN 3  -  P1.2  -  SCK - SPI-Clock
 * PIN 4  -  P1.1  -  SDI - SPI-Dateninput
 * PIN 5  -   ./.  -  _LDAC = GND
 * PIN 6  -   ./.  -  VREF  = +3,3V
 * PIN 7  -   ./.  -  VSS   = GND
 * PIN 8  -   ./.  -  VOUT
 *
 */
#include	"main.h"



void main(void) {
	vCPU_init();
	vSPI_init();

	vLCD_init(16);
	vLCD_puts("MCP4921 02.04.13");

	while(42) {
		DAC_sinus();
	}
}


void vCPU_init(void) {
	WDTCTL = WDTPW + WDTHOLD;	// stop watchdog-timer

	DCOCTL = CALDCO_1MHZ;		// interner Oszillator @ 1Mhz
	BCSCTL1 = CALBC1_1MHZ;
	BCSCTL2 = 0;
	BCSCTL3 = 0;
}

// msec Millisekunden lang zhlen
void vdelay_ms(unsigned int msec) {
  volatile unsigned int count;

	while(--msec) {
		count = 86;	// funktioniert bei 1MHz aus dem internen Oszillator DCO
		while(count) {
			--count;
		}
	}
}



// Dummy: um Warnungen zu vermeiden
#pragma vector = PORT1_VECTOR, PORT2_VECTOR, ADC10_VECTOR, USCIAB0TX_VECTOR, USCIAB0RX_VECTOR, TIMER1_A1_VECTOR, TIMER0_A0_VECTOR, TIMER0_A1_VECTOR, TIMER1_A0_VECTOR, WDT_VECTOR, COMPARATORA_VECTOR, NMI_VECTOR
__interrupt void USCIAB0TX_ISR(void)
{
}

// Ende main.c
